@@ -703,7 +703,13 @@ DefaultAction.prototype.entityDoubleClicked = function(entityId, event) {
 
         if (RSettings.getBoolValue("GraphicsView/DoubleClickSelectContour", true)===true) {
             include("scripts/Select/SelectContour/SelectContour.js");
-            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, 0.001);
+            var tol = RSettings.getDoubleValue("GraphicsView/DoubleClickSelectContourTolerance", 0.001);
+            var layerId = RObject.INVALID_ID;
+            if (isAltPressed(event)) {
+                // Alt: restrict to same layer:
+                layerId = entity.getLayerId();
+            }
+            var matchingEntityIds = SelectContour.getConnectedEntities(this.document, entityId, tol, layerId);
             var add = isShiftPressed(event);
             if (entity.isSelected()) {
                 this.di.selectEntities(matchingEntityIds, add);
